<?php
class Calendarista_OptionalRepository extends Calendarista_RepositoryBase{
	private $wpdb;
	private $optional_table_name;
	private $optional_booked_table_name;
	public function __construct(){
		global $wpdb;
		$this->wpdb = &$wpdb;
		$this->optional_table_name = $wpdb->prefix . 'calendarista_optional';
		$this->optional_booked_table_name = $wpdb->prefix . 'calendarista_optionals_booked';
	}
	
	public function readAll($projectId){
		$sql = "SELECT t1.*, (SELECT count(*) FROM $this->optional_booked_table_name as t2 WHERE t2.optionalId = t1.id) as bookedQuantity FROM $this->optional_table_name as t1 WHERE  projectId = %d ORDER BY orderIndex";
		$result = $this->wpdb->get_results( $this->wpdb->prepare($sql, $projectId) );
		if ( is_array($result) ){
			$optionals = new Calendarista_Optionals();
			foreach($result as $r){
				$optionals->add( new Calendarista_Optional((array)$r));
			}
			return $optionals;
		}
		return false;
	}
	public function readAllByIdList($list){
		$sql = sprintf('SELECT t1.*, (SELECT count(*) FROM %s as t2 WHERE t2.optionalId = t1.id) as bookedQuantity FROM   %s as t1 WHERE  id in (%s) ORDER BY orderIndex', $this->optional_booked_table_name, $this->optional_table_name, implode(',', $list));
		$result = $this->wpdb->get_results($sql);
		if ( is_array($result) ){
			$optionals = new Calendarista_Optionals();
			foreach($result as $r){
				$optionals->add( new Calendarista_Optional((array)$r));
			}
			return $optionals;
		}
		return false;
	}
	public function readAllByGroup($groupId){
		$sql = "SELECT t1.*, (SELECT count(*) FROM $this->optional_booked_table_name as t2 WHERE t2.optionalId = t1.id) as bookedQuantity FROM $this->optional_table_name as t1  WHERE  t1.groupId = %d ORDER BY orderIndex";
		$result = $this->wpdb->get_results( $this->wpdb->prepare($sql, $groupId) );
		if ( is_array($result) ){
			$optionals = new Calendarista_Optionals();
			foreach($result as $r){
				$optionals->add( new Calendarista_Optional((array)$r));
			}
			return $optionals;
		}
		return false;
	}
	
	public function read($id){
		$sql = "SELECT t1.*, (SELECT count(*) FROM $this->optional_booked_table_name as t2 WHERE t2.optionalId = t1.id) as bookedQuantity FROM $this->optional_table_name as t1 WHERE  id = %d";
		$result = $this->wpdb->get_results( $this->wpdb->prepare($sql, $id) );
		if( $result ){
			$r = $result[0];
			return new Calendarista_Optional((array)$r);
		}
		return false;
	}
	
	public function insert($optional){
		 $result = $this->wpdb->insert($this->optional_table_name,  array(
			'projectId'=>$optional->projectId
			, 'groupId'=>$optional->groupId
			, 'name'=>$this->encode($optional->name)
			, 'cost'=>$optional->cost
			, 'quantity'=>$optional->quantity
			, 'doubleCostIfReturn'=>$optional->doubleCostIfReturn
		  ), array('%d', '%d', '%s', '%f', '%d', '%d'));
		  
		 if($result !== false){
			$optional->id = $this->wpdb->insert_id;
			$this->updateSortOrder($optional->id, $optional->id);
			$optional->updateResources();
			return $optional->id;
		 }
		 return $result;
	}
	
	public function update($optional){
		$result = $this->wpdb->update($this->optional_table_name,  array(
			'groupId'=>$optional->groupId
			, 'orderIndex'=>$optional->orderIndex
			, 'name'=>$this->encode($optional->name)
			, 'cost'=>$optional->cost
			, 'quantity'=>$optional->quantity
			, 'doubleCostIfReturn'=>$optional->doubleCostIfReturn
		), array('id'=>$optional->id), array('%d', '%d', '%s', '%f', '%d', '%d'));
		$optional->updateResources();
		return $result;
	}
	
	public function updateSortOrder($id, $orderIndex){
		$result = $this->wpdb->update($this->optional_table_name,  array(
			'orderIndex'=>$orderIndex
		), array('id'=>$id), array('%d'));
		return $result;
	}
	
	public function delete($id){
		$this->deleteResources($id);
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->optional_table_name WHERE id = %d", $id));
	}
	public function deleteByGroup($id){
		$optionals = $this->readAllByGroup($id);
		foreach($optionals as $optional){
			$this->deleteResources($optional->id);
		}
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->optional_table_name WHERE groupId = %d", $id));
	}
	public function deleteAll($id){
		$optionals = $this->readAll($id);
		if($optionals->count() === 0){
			return;
		}
		foreach($optionals as $optional){
			$optional->deleteResources();
		}
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->optional_table_name WHERE projectId = %d", $id));
	}
	public function deleteResources($id){
		$optional = $this->read($id);
		if($optional){
			$optional->deleteResources();
		}
	}
}
?>