<?php
class Calendarista_TimeslotRepository extends Calendarista_RepositoryBase{
	private $wpdb;
	private $timeslot_table_name;
	
	public function __construct(){
		global $wpdb;
		$this->wpdb = &$wpdb;
		$this->timeslot_table_name = $wpdb->prefix . 'calendarista_timeslot';
	}
	
	public function readAll($projectId){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  projectId = %d ORDER BY TIME(timeslot)";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $projectId));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	
	public function readAllByAvailability($availabilityId){
		$sql = "SELECT *
				FROM   $this->timeslot_table_name 
				WHERE  availabilityId = %d
				ORDER BY TIME(timeslot)";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function readAllByStartEnd($startId, $endId){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  id BETWEEN %d AND %d ORDER BY TIME(timeslot)";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $startId, $endId));
		if (is_array($result)){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function readAllWeekdaysByAvailability($availabilityId){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  availabilityId = %d AND weekday IS NOT NULL ORDER BY TIME(timeslot)";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function readAllDaysByAvailability($availabilityId){
		$sql = "SELECT DISTINCT day FROM   $this->timeslot_table_name WHERE  availabilityId = %d AND day IS NOT NULL ORDER BY day";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId));
		if ( is_array($result) ){
			$dates = array();
			foreach($result as $r){
				array_push($dates, date(CALENDARISTA_DATEFORMAT, strtotime($r->day)));
			}
			return $dates;
		}
		return false;
	}
	public function readSingleDayByAvailability($selectedDate/*as string*/, $availabilityId){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  availabilityId = %d AND DATE(day) = CONVERT('%s', DATE) ORDER BY TIME(timeslot)";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId, $selectedDate));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function readAllByWeekday($weekday, $availabilityId = null){
		$sql = "SELECT * FROM   $this->timeslot_table_name";
		$where = array();
		if($weekday !== null){
			array_push($where, 'weekday = %d');
		}
		if($availabilityId !== null){
			array_push($where, 'availabilityId = %d');
		}
		if(count($where) > 0){
			$sql .= ' WHERE ' . implode(' AND ', $where);
		}
		$sql .= ' ORDER BY TIME(timeslot)';
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $weekday, $availabilityId));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function readAllByDate($day, $projectId, $availabilityId = null){
		$sql = "SELECT * FROM   $this->timeslot_table_name";
		$where = array();
		$params = array($day);
		array_push($where, 'DATE(day) = CONVERT(%s, DATE)');
		if($projectId !== null){
			array_push($where, 'projectId = %d');
			array_push($params, $projectId);
		}
		if($availabilityId !== null){
			array_push($where, 'availabilityId = %d OR availabilityId IS NULL');
			array_push($params, $availabilityId);
		}
		if(count($where) > 0){
			$sql .= ' WHERE ' . implode(' AND ', $where);
		}
		$sql .= ' ORDER BY TIME(timeslot)';
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $params));
		if ( is_array($result) ){
			$timeslots = new Calendarista_Timeslots();
			foreach($result as $r){
				$timeslots->add( new Calendarista_Timeslot((array)$r));
			}
			return $timeslots;
		}
		return false;
	}
	public function read($id){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  id = %d";
		$result = $this->wpdb->get_results( $this->wpdb->prepare($sql, $id) );
		if($result){
			$r = $result[0];
			return new Calendarista_Timeslot((array)$r);
		}
		return false;
	}
	public function readByTimeslot($availabilityId, $selectedDate, $weekday, $timeslot){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  availabilityId = %d AND (DATE(day) = CONVERT('%s', DATE) OR (weekday = %d AND timeslot = '%s'))";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId, $selectedDate, $weekday, $timeslot));
		if($result){
			$r = $result[0];
			return new Calendarista_Timeslot((array)$r);
		}
		return false;
	}
	public function readByTimeslotId($availabilityId, $selectedDate, $weekday, $timeslotId){
		$sql = "SELECT * FROM   $this->timeslot_table_name WHERE  availabilityId = %d AND (DATE(day) = CONVERT('%s', DATE) OR (weekday = %d AND timeslot = (SELECT timeslot FROM  $this->timeslot_table_name WHERE id = %d)))";
		$result = $this->wpdb->get_results($this->wpdb->prepare($sql, $availabilityId, $selectedDate, $weekday, $timeslotId));
		if($result){
			$r = $result[0];
			return new Calendarista_Timeslot((array)$r);
		}
		return false;
	}
	public function insert($timeslot){
		$params = $this->parseParms($timeslot);
		$result = $this->wpdb->insert($this->timeslot_table_name,  $params[0], $params[1]);
		if($result !== false){
			return $this->wpdb->insert_id;
		}
		return $result;
	}
	
	public function update($timeslot){
		$params = $this->parseParms($timeslot);
		$result = $this->wpdb->update($this->timeslot_table_name,  $params[0], array('id'=>$timeslot->id), $params[1]);
		return $result;
	}
	public function updateDeals($availabilityId, $deals){
		$result = $this->wpdb->update($this->timeslot_table_name,  array('deal'=>0), array('availabilityId'=>$availabilityId), array('%d'));
		if($deals){
			foreach($deals as $id){
				$result = $this->wpdb->update($this->timeslot_table_name,  array('deal'=>1), array('id'=>(int)$id), array('%d'));
			}
		}
		return $result;
	}
	public function updateSeat($timeslot, $seats = 1, $oldSeats = 0){
		$bookedSeats = $timeslot->bookedSeats;
		if($oldSeats > 0){
			$bookedSeats -= $oldSeats;
		}
		$seats += $bookedSeats;
		return $this->wpdb->update($this->timeslot_table_name,  array('bookedSeats'=>$seats), array('id'=>$timeslot->id), array('%d'));
	}
	public function updateSeatById($id, $seats = 1, $oldSeats = 0){
		$timeslot = $this->read($id);
		if($timeslot){
			$bookedSeats = $timeslot->bookedSeats;
			if($oldSeats > 0){
				$bookedSeats -= $oldSeats;
			}
			$seats += $bookedSeats;
			return $this->wpdb->update($this->timeslot_table_name,  array('bookedSeats'=>$seats), array('id'=>$id), array('%d'));
		}
		return false;
	}
	public function parseParms($timeslot){
		$params = array(
			'timeslot'=>$timeslot->timeslot
			, 'cost'=>$timeslot->cost
			, 'bookedSeats'=>$timeslot->bookedSeats
		);
		$values = array('%s','%f', '%d');
		if(isset($timeslot->availabilityId)){
		  $params['availabilityId'] = $timeslot->availabilityId;
		  array_push($values, '%d');
		}
		if(isset($timeslot->weekday) && $timeslot->weekday !== -1){
		  $params['weekday'] = $timeslot->weekday;
		  array_push($values, '%d');
		}
		if(isset($timeslot->day)){
		  $params['day'] = $timeslot->day->format(CALENDARISTA_DATEFORMAT);
		  array_push($values, '%s');
		}
		if(isset($timeslot->projectId)){
		  $params['projectId'] = $timeslot->projectId;
		  array_push($values, '%d');
		}
		if(isset($timeslot->seats)){
		  $params['seats'] = $timeslot->seats;
		  array_push($values, '%d');
		}
		if(isset($timeslot->seatsMaximum)){
		  $params['seatsMaximum'] = $timeslot->seatsMaximum;
		  array_push($values, '%d');
		}
		if(isset($timeslot->seatsMinimum)){
		  $params['seatsMinimum'] = $timeslot->seatsMinimum;
		  array_push($values, '%d');
		}
		if(isset($timeslot->bookedSeats)){
		  $params['bookedSeats'] = $timeslot->bookedSeats;
		  array_push($values, '%d');
		}
		if(isset($timeslot->paddingTimeBefore)){
		  $params['paddingTimeBefore'] = $timeslot->paddingTimeBefore;
		  array_push($values, '%d');
		}
		if(isset($timeslot->paddingTimeAfter)){
		  $params['paddingTimeAfter'] = $timeslot->paddingTimeAfter;
		  array_push($values, '%d');
		}
		
		$params['deal'] = $timeslot->deal;
		array_push($values, '%d');
		
		return array($params, $values);
	}
	public function delete($id){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE id = %d", $id));
	}
	public function deleteAllByAvailability($id){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE availabilityId = %d", $id));
	}
	public function deleteWeekdaysByAvailability($id){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE availabilityId = %d AND weekday IS NOT NULL", $id));
	}
	public function deleteByWeekday($availabilityId, $weekday){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE availabilityId = %d AND weekday = %d", $availabilityId, $weekday));
	}
	public function deleteByDate($availabilityId, $date){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE availabilityId = %d AND DATE(day) = CONVERT(%s, DATE)", $availabilityId, $date));
	}
	public function deleteByProject($projectId){
		return $this->wpdb->query($this->wpdb->prepare("DELETE FROM $this->timeslot_table_name WHERE projectId = %d", $projectId));
	}
}
?>