<?php
class Calendarista_EmailReminderJob{
	const HOOK = 'Calendarista_EmailReminderJobEventHook';
	public function __construct($orderId, $projectId)
	{
		$generalSetting = Calendarista_GeneralSettingHelper::get();
		if (!$generalSetting->reminderAltCronJob){
			return;
		}
		if($orderId && $projectId){
			$projectRepo = new Calendarista_ProjectRepository();
			$project = $projectRepo->read($projectId);
			if($project && $project->reminder){
				$this->schedule($project->reminder, $orderId);
			}
		}
	}
	public function schedule($reminder, $orderId){
		$bookedAvailabilityRepo = new Calendarista_BookedAvailabilityRepository();
		$bookedAvailabilityList = $bookedAvailabilityRepo->readByOrderId($orderId);
		$timezone = get_option('timezone_string');
		$originalTimezone = null;
		if($timezone){
			$originalTimezone = Calendarista_TimeHelper::setTimezone($timezone);
		}
		foreach($bookedAvailabilityList as $bookedAvailability){
			if((int)$bookedAvailability->status === Calendarista_AvailabilityStatus::CANCELLED){
				return;
			}
			$scheduleDate = new Calendarista_DateTime($bookedAvailability->fromDate);
			$now = new Calendarista_DateTime();
			$scheduleDate->modify("-{$reminder} minutes");
			if ($scheduleDate > $now && !self::schedulePending($orderId))
			{
				$result = wp_schedule_single_event(strtotime($scheduleDate->format('Y-m-d H:i:s'))/*time() + 30*/, self::HOOK, array($orderId));
			}
		}
		if($originalTimezone){
			Calendarista_TimeHelper::setTimezone($originalTimezone);
		}
	}
	public static function init($orderId){
		if(!$orderId){
			return;
		}
		$bookedAvailabilityRepo = new Calendarista_BookedAvailabilityRepository();
		$bookedAvailabilityList = $bookedAvailabilityRepo->readByOrderId($orderId);
		foreach($bookedAvailabilityList as $bookedAvailability){
			if((int)$bookedAvailability->status === Calendarista_AvailabilityStatus::CANCELLED){
				return;
			}
		}
		$notification = new Calendarista_NotificationEmailer(array(
			'orderId'=>(int)$orderId
			, 'emailType'=>Calendarista_EmailType::BOOKING_REMINDER
		));
		$notification->send();
		$reminderRepo = new Calendarista_RemindersRepository();
		$reminderRepo->insert(new Calendarista_EmailReminder(array(
			'fullName'=>$notification->order->fullName
			, 'email'=>$notification->order->email
			, 'sentDate'=>new Calendarista_DateTime()
			, 'orderId'=>(int)$orderId
			, 'projectId'=>$notification->order->projectId
		)));
	}
	public static function register(){
		add_action(self::HOOK, array('Calendarista_EmailReminderJob', 'init'), 10, 1);
	}
	public static function getSchedulesCount(){
		$crons = _get_cron_array();
		$result = 0;
		foreach ($crons as $timestamp=>$hooks) { 
			foreach ((array)$hooks as $hook=>$params) {
				if(strpos($hook, self::HOOK)!== false){
					++$result;
				}
			}
		}
		return $result;
	}
	public static function cancelSchedule($orderId){
		$crons = _get_cron_array();
		foreach ($crons as $timestamp=>$hooks) { 
			foreach ((array)$hooks as $hook=>$params) {
				if(strpos($hook, self::HOOK)!== false && $params[key($params)]['args'][0] == $orderId){
					wp_clear_scheduled_hook($hook, $params[key($params)]['args']);
					break 2;
				}
			}
		}
	}
	public static function cancelAllSchedules(){
		$crons = _get_cron_array();
		foreach ($crons as $timestamp=>$hooks) { 
			foreach ((array)$hooks as $hook=>$params) {
				if(strpos($hook, self::HOOK)!== false){
					wp_clear_scheduled_hook($hook, $params[key($params)]['args']);
				}
			}
		}
	}
	public static function schedulePending($orderId){
		$result = false;
		$crons = _get_cron_array();
		foreach ($crons as $timestamp=>$hooks) { 
			foreach ((array)$hooks as $hook=>$params) {
				if(strpos($hook, self::HOOK) !== false){
					$args = $params[key($params)]['args'];
					if($args[0] == $orderId){
						$result = true;
						break 2;
					}
				}
			}
		}
		return $result;
	}
}
?>