<?php
class Calendarista_SearchResultList extends Calendarista_UList {
	public $perPage;
	public $orderBy;
	public $projects;
	protected $pages;
	protected $generalSetting;
	protected $tagsRepo;
  function __construct($projects = null){
	  $this->projects = $projects;
	  $this->pages = $this->prepareGetPageLink();
		parent::__construct( array(
            'singular'  => 'order', 
            'plural'    => 'orders', 
            'ajax'      => false    
        ) );
		$repo = new Calendarista_GeneralSettingsRepository();
		$this->generalSetting = $repo->read();
		$this->tagsRepo = new Calendarista_TagsRepository();
    }
    
	function single_row( $item ) {
		echo $this->single_row_columns( $item );
	}
	
    function column_default($item, $column_name){
        switch($column_name){
            default:
                return print_r($item,true); 
        }
    }
    
	function column_item($item){
		$thumbnail = null;
		$pageId = $item['pageId'];
		$url = $this->getPageUrl($pageId);
		$tagResult = $this->tagsRepo->readAllByAvailability(array('availabilityId'=>(int)$item['id']));
		if($url){
			$url .= (strpos($url,'?') !== false) ? '&' : '?';
			$url .= sprintf('cal-service-id=%s&cal-availability-id=%s'
							, $item['serviceId']
							, $item['availabilityId']);
		}
		if($item['start'] && $url){
			$url .= sprintf('&cal-start=%s&cal-end=%s', $item['start'], $item['end']);
			if($item['startTime']){
				$url .= sprintf('&cal-start-time=%s', $item['startTime']);
			}
			if($item['endTime']){
				$url .= sprintf('&cal-end-time=%s', $item['endTime']);
			}
		}
		if($item['thumbnail']){
			$thumbnail = sprintf('<img src="%s" alt="...">', $item['thumbnail']);
			if($url){
				$thumbnail = sprintf('<a href="%s" target="_blank">%s</a>', $url, $thumbnail);
			}
		}
		
		//SEARCH_BUTTON_SELECT
		$title = $url ? sprintf('<a href="%s" class="calendarista-media-link" target="_blank">%s</a>', $url, $item['title']) : $item['title'];
		$goToLink = $url ? sprintf('<a class="btn btn-primary calendarista-typography--button" href="%s" target="_blank">%s</a>', $url, $this->generalSetting->searchFilterSelectButtonLabel) : '';
		$description = null;
		if(!$item['active']){
			$title = $item['title'];
			$goToLink = null;
			$description = sprintf('<div class="mb-1"><span class="badge bg-danger">%s</span></div>', $this->generalSetting->searchFilterSoldOutLabel);
		}else if(!$item['status']){
			$description = sprintf('<div class="mb-1"><span class="badge bg-warning">%s</span></div>', $this->generalSetting->searchFilterAlternateDateLabel);
		}
		if($item['description']){
			$description .= '<div class="mb-1">' . $item['description'] . '</div>';
		}
		if($tagResult){
			$tags = $tagResult['items'];
			if(count($tags) > 0){
				$description .= '<div class="mb-1">';
				foreach($tags as $tag){
					$description .= sprintf('<span class="badge rounded-pill bg-secondary">%s</span>&nbsp;', $tag->name);
				}
				$description .= '</div>';
			}
		}
		$result = '<div class="container">';
		$result .= 		'<div class="row align-items-center">';
		$result .= 			'<div class="col">';
		$result .= 				'<div class="container">';
		$result .= 					'<div class="row align-items-center">';
		if($thumbnail){
			$result .= 					'<div class="col-md-auto">' . $thumbnail . '</div>';
		}
		$result .= 							'<div class="col-md-auto h-100">';
		$result .= 								'<h5 class="mb-1">' . $title . '</h5>';
		$result .= 								'<div class="mb-1">' . $item['subTitle'] . '</div>';
		$result .= $description;
		$result .= 						'</div>';//col h-100
		$result .= 					'</div>';//row
		$result .= 				'</div>';//container
		$result .= 			'</div>';//col-10
		$result .= 			'<div class="col-md-auto">';
		$result .= 				'<div class="container">';
		$result .= 					'<div class="row">';
		$result .= 						'<div class="col">';
		$result .= 							'<div class="align-items-center h-100 w-100">';
		$result .=								'<div class="align-self-center">';
		$result .= 									$goToLink;
		$result .=								'</div>';//align-self-center
		$result .=							'</div>';//align-items-center h-100 w-100
		$result .=						'</div>';//col
		$result .=					'</div>';//row
		$result .=				'</div>';//container
		$result .= 			'</div>';//col-2
		$result .= 		'</div>';//row
		$result .= 	'</div>';//container
		return $result;
	}
	
	
    function get_columns(){
        $columns = array(
			'item'=>''
        );
		
        return $columns;
    }
    
    function get_sortable_columns() {
		//true means its already sorted
        $sortable_columns = array();
        return $sortable_columns;
    }
    
    /**
		@description binds to data
	*/
    function bind() {
        $per_page = 10;
        
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        
        $this->_column_headers = array($columns, $hidden, $sortable);
        $currentPage = $this->get_pagenum() - 1;
		if($currentPage){
			$currentPage = $currentPage * $per_page;
		}
		$projectId = isset($_REQUEST['projectId']) ? (int)$_REQUEST['projectId'] : null;
		$projectList = (isset($_REQUEST['projectList']) && $_REQUEST['projectList']) ? explode(',', $_REQUEST['projectList']) : null;
		$tags = (isset($_REQUEST['tags']) && $_REQUEST['tags']) ? explode(',', $_REQUEST['tags']) : null;
		$startDate = isset($_REQUEST['fromDate']) ? $_REQUEST['fromDate'] : null;
		$endDate = isset($_REQUEST['toDate']) ? $_REQUEST['toDate'] : null;
		$startTime = isset($_REQUEST['fromTime']) ? $_REQUEST['fromTime'] : null;
		$endTime = isset($_REQUEST['toTime']) ? $_REQUEST['toTime'] : null;
		if($projectId){
			$this->projects = array($projectId);
		}
		if($projectList && count($projectList) > 0){
			$this->projects = $projectList;
		}
		if($startDate && $startTime){
			$startDate .= ' ' . $startTime;
		}
		if($endDate && $endTime){
			$endDate .= ' ' . $endTime;
		}
		if($endDate && !$startDate){
			$startDate = $endDate;
		}
		$availabilityRepository = new Calendarista_AvailabilityRepository();
        $result = $availabilityRepository->search(array(
			'pageIndex'=>$currentPage
			, 'limit'=>$per_page
			, 'startDate'=>$startDate
			, 'endDate'=>$endDate
			, 'services'=>$this->projects
			, 'tags'=>$tags
		));
		if(!$result){
			$this->items = array();
			$this->set_pagination_args(array(
				'total_items' => 0,
				'per_page'    => $per_page,
				'total_pages' => $total_pages
			));
			return;
		}
		$total = $result['total'];
		$items = array();
		//we need these two fields in availability
		//1. enable image only for search
		//2. page url where the service short-code is used
		$sd = new Calendarista_DateTime($startDate);
		$ed = new Calendarista_DateTime($endDate);
		if(!$endDate){
			$endDate = $startDate;
		}
		$diff = $sd->diff($ed);
		foreach($result['resultset'] as $availability){
			$active = Calendarista_AvailabilityHelper::active($availability);
			$resultset = Calendarista_AvailabilityHelper::checkAvailability($availability, $startDate, $endDate);
			if($availability->bookingDaysMinimum > 0 && $diff->days < $availability->bookingDaysMinimum){
				--$total;
				continue;
			}
			if($availability->bookingDaysMaximum > 0 && $diff->days > $availability->bookingDaysMaximum){
				--$total;
				continue;
			}
			array_push($items, array(
				'id'=>$availability->id
				, 'title'=>is_array($resultset) ? $resultset['serviceName'] : $resultset
				, 'subTitle'=>$availability->name
				, 'description'=>$availability->description
				, 'thumbnail'=>$availability->searchThumbnailUrl
				, 'pageId'=>$availability->searchPage ? $availability->searchPage : null
				, 'serviceId'=>$availability->projectId
				, 'availabilityId'=>$availability->id
				, 'active'=>$active
				, 'status'=>!is_array($resultset) ? false : true
				, 'start'=>is_array($resultset) ? $resultset['startDate'] : null
				, 'startTime'=>is_array($resultset) ? $startTime : null
				, 'end'=>is_array($resultset) ? $resultset['endDate'] : null 
				, 'endTime'=>is_array($resultset) ? $endTime : null
			));
		}
        $total_pages = ceil($total / $per_page);
        $this->items = $items;
        $this->set_pagination_args(array(
            'total_items' => $total,
            'per_page'    => $per_page,
            'total_pages' => $total_pages
        ));
    }
	protected function getPageUrl($id){
		if(!$id){
			return null;
		}
		return get_page_link($id);
	}
	protected function prepareGetPageLink(){
		Calendarista_PermissionHelper::wpIncludes();
		if (!function_exists('get_page_permastruct')){
			require_once ABSPATH . WPINC . '/class-wp-rewrite.php';
			$GLOBALS['wp_rewrite'] = new WP_Rewrite();
		}
		if (!function_exists('get_page_link')){
			require_once ABSPATH . WPINC . '/link-template.php ';
		}
	}
	function get_table_classes() {
		return array('calendarista-search-list list-group');
	}
	public function no_items() {
		echo __('No items found.', 'calendarista');
	}
}
?>