<?php
class Calendarista_AppointmentHelper{
	public static function getAppointmentViewState($orderId, $availabilityId = null){
		$orderRepo = new Calendarista_OrderRepository();
		$order = $orderRepo->read($orderId);
		if(!$availabilityId){
			$availabilityId = $order->availabilityId;
		}
		$bookedAvailabilityRepo = new Calendarista_BookedAvailabilityRepository();
		$bookedAvailabilityList = $bookedAvailabilityRepo->readByOrderId($orderId);
		$dynamicFieldRepo = new Calendarista_BookedDynamicFieldRepository();
		$dynamicFields = $dynamicFieldRepo->readByOrderId($orderId);
		$bookedMapRepo = new Calendarista_BookedMapRepository();
		$map = $bookedMapRepo->readByOrderId($orderId);
		$bookedWaypointRepo = new Calendarista_BookedWaypointRepository();
		$waypoints = $bookedWaypointRepo->readByOrderId($orderId);
		$bookedOptionalRepo = new Calendarista_BookedOptionalRepository();
		$optionals = $bookedOptionalRepo->readAll($orderId);
		$bookedFormElementRepo = new Calendarista_BookedFormElementRepository();
		$bookedFormFields = $bookedFormElementRepo->readAll($orderId);
		$orderAvailabilityRepo = new Calendarista_OrderAvailabilityRepository();
		$orderAvailabilityList = $orderAvailabilityRepo->readAll($orderId);
		$availabilities = array();
		if($orderAvailabilityList && count($orderAvailabilityList) > 0){
			foreach($orderAvailabilityList as $oal){
				array_push($availabilities, $oal['availabilityId']);
			}
		}
		$enableMultipleBooking = count($availabilities) > 0;
		if($enableMultipleBooking){
			if($availabilityId != $order->availabilityId && !in_array($order->availabilityId, $availabilities)){
				array_push($availabilities, $order->availabilityId);
			}
		}
		$result = array();
		if(!($bookedAvailabilityList && count($bookedAvailabilityList) > 0)){
			return $result;
		}
		$bookedAvailability = $bookedAvailabilityList[0];
		foreach($bookedAvailabilityList as $ba){
			if((int)$ba->availabilityId === $availabilityId){
				$bookedAvailability = $ba;
				break;
			}
		}
		$result[0] = array('projectId'=>$order->projectId, 'orderId'=>$orderId);
		$result[1] = array(
			'availabilityId'=>(int)$bookedAvailability->availabilityId
			, 'availableDate'=>date(CALENDARISTA_DATEFORMAT, strtotime($bookedAvailability->fromDate))
			, 'endDate'=>date(CALENDARISTA_DATEFORMAT, strtotime($bookedAvailability->toDate))
			, '_availabilityId'=>(int)$bookedAvailability->availabilityId
			, '_availableDate'=>$bookedAvailability->fromDate
			, '_endDate'=>$bookedAvailability->toDate
			, 'startTimeslot'=>$bookedAvailability->startTimeId
			, 'endTimeslot'=>$bookedAvailability->endTimeId
			, 'startTime'=>null
			, 'endTime'=>null
			, 'seats'=>(int)$bookedAvailability->seats
			, 'timezone'=>$bookedAvailability->timezone
			, 'multiDateSelection'=>self::getMultiDateSelection($bookedAvailabilityList)
			, 'dynamicFields'=>self::getDynamicFields($dynamicFields)
			, 'availabilities'=>implode(',', $availabilities)
			, 'enableMultipleBooking'=>$enableMultipleBooking
		);
		$result[1] = self::fillStartEndTime($result[1], $bookedAvailability);
		if($map){
			$result[2] = array(
				'fromAddress'=>$map->fromAddress
				, 'fromLat'=>$map->fromLat
				, 'fromLng'=>$map->fromLng
				, 'toAddress'=>$map->toAddress
				, 'toLat'=>$map->toLat
				, 'toLng'=>$map->toLng
				, 'distance'=>(float)$map->distance
				, 'duration'=>(float)$map->duration
				, 'unitType'=>(int)$map->unitType
				, 'waypoints'=>$waypoints ? $waypoints : array()
				, 'fromPlaceId'=>$map->fromPlaceId
				, 'toPlaceId'=>$map->toPlaceId
			);
		}
		if($optionals){
			$listOfOptionals = array();
			foreach($optionals as $o){
				$listOfOptionals = array_merge($listOfOptionals, $o);
			}
			$result[3] = array('optionals'=>implode(',', array_map(array('Calendarista_AppointmentHelper', 'getOptionalId'), $listOfOptionals)));
		}
		$result[4] = array(
			'formelements'=>array_map(array('Calendarista_AppointmentHelper', 'convertFormFieldObjectToArray'), $bookedFormFields)
			, 'userId'=>$order->userId
			, 'name'=>$order->fullName
			, 'email'=>$order->email
		);
		$result[5] = array('status'=>(int)$bookedAvailability->status);
		$result[6] = array('discount'=>$order->discount, 'discountMode'=>$order->discountMode);
		$result[7] = array('invoiceId'=>$order->invoiceId);
		$result[8] = array('tax'=>$order->tax);
		$result[9] = array('taxMode'=>$order->taxMode);
		$result[10] = array('paymentOperator'=>$order->paymentDate ? $order->paymentOperator : null);
		return $result;
	}
	public static function getMultiDateSelection($bookedAvailabilityList){
		$result = array();
		if($bookedAvailabilityList && (count($bookedAvailabilityList) > 0 && in_array((int)$bookedAvailabilityList[0]->calendarMode, Calendarista_CalendarMode::$SUPPORTS_MULTI_DATE))){
			foreach($bookedAvailabilityList as $bookedAvailability){
				$fromDate = date(CALENDARISTA_DATEFORMAT, strtotime($bookedAvailability->fromDate));
				if((int)$bookedAvailability->calendarMode === Calendarista_CalendarMode::MULTI_DATE){
					array_push($result, $fromDate);
				}else{
					array_push($result, sprintf('%s:%s', $fromDate, $bookedAvailability->startTimeId));
				}
			}
		}
		return implode(';', $result);
	}
	public static function fillStartEndTime($args, $bookedAvailability){
		if(!isset($bookedAvailability->startTimeId)){
			return $args;
		}
		//since you can technically regenerate timeslots, get timeslot id from timeslots table, query by time
		$timeslotRepo = new Calendarista_TimeslotRepository();
		$fd = strtotime($bookedAvailability->fromDate);
		$args['startTimeslot'] = date('g:i a', $fd);
		$fromDate = date(CALENDARISTA_DATEFORMAT, $fd);
		$fromWeekday = (int)date('N', $fd);
		$startTimeslot = $timeslotRepo->readByTimeslot((int)$bookedAvailability->availabilityId, $fromDate, $fromWeekday, $args['startTimeslot']);
		if($startTimeslot){
			$args['startTime'] = (int)$startTimeslot->id;
		}
		if(isset($bookedAvailability->endTimeId)){
			$td = strtotime($bookedAvailability->toDate);
			$args['endTimeslot'] = date('g:i a', $td);
			$toDate = date(CALENDARISTA_DATEFORMAT, $td);
			$toWeekday = (int)date('N', $td);
			$endTimeslot = $timeslotRepo->readByTimeslot((int)$bookedAvailability->availabilityId, $toDate, $toWeekday, $args['endTimeslot']);
			if($endTimeslot){
				$args['endTime'] = (int)$endTimeslot->id;
			}
		}
		return $args;
	}
	public static function getOptionalId($optional){
		return (int)$optional->optionalId;
	}
	public static function convertFormFieldObjectToArray($formField){
		return array(
			'projectId'=>(int)$formField->projectId
			, 'elementId'=>(int)$formField->elementId
			, 'orderIndex'=>(int)$formField->orderIndex
			, 'value'=>$formField->value
			, 'label'=>$formField->label
		);
	}
	public static function getDynamicFields($items){
		$fields = array();
		if(is_array($items) && count($items) > 0){
			foreach($items as $item){
				array_push($fields, array(
					'id'=>(int)$item['dynamicFieldId']
					, 'value'=>(int)$item['value']
					, 'label'=>$item['label']
					, 'cost'=>$item['cost']
					, 'limitBySeat'=>$item['limitBySeat']
					, 'byOptional'=>$item['byOptional']
				));
			}
		}
		return $fields;
	}
    private function __construct() { }
}
?>