<?php
class Calendarista_BookMoreTmpl extends Calendarista_TemplateBase{
	public $appointment;
	public $selectedAvailabilities;
	public function __construct(){
		parent::__construct();
		$projectId = (int)$this->getPostValue('projectId');
		$startDate = $this->getPostValue('startDate');
		$endDate = $this->getPostValue('endDate');
		$startTime = $this->getPostValue('startTime') ? (int)$this->getPostValue('startTime') : null;
		$endTime = $this->getPostValue('endTime') ? (int)$this->getPostValue('endTime') : null;
		$availabilityId = (int)$this->getPostValue('availabilityId');
		$seats = (int)$this->getPostValue('seats');
		$this->selectedAvailabilities = $this->getViewStateValue('availabilities') ? explode(',', $this->getViewStateValue('availabilities')) : array();
		$this->appointment = (int)$this->getPostValue('appointment', -1);
		$availabilityRepo = new Calendarista_AvailabilityRepository();
		$availabilities = $availabilityRepo->readAll($projectId);
		$this->availabilities = array();
		foreach($availabilities as $availability){
			if($availability->id === $availabilityId){
				continue;
			}
			$flag = false;
			if($availability->seats === 0){
				//seats are unlimited.
				$flag = true;
			}else{
				$availabilityHelper = new Calendarista_AvailabilityHelper(array(
					'projectId'=>$projectId
					, 'availabilityId'=>$availability->id
				));
				if(in_array($availabilityHelper->project->calendarMode, array(Calendarista_CalendarMode::PACKAGE))){
					$result = $availabilityHelper->getNextOccurrenceByPackage();
					if($result){
						$flag = true;
					}
				}else{
					$result = $this->getSeats($availabilityHelper, $startDate, $startTime, $endDate, $endTime);
					if($result && ($result >= $availability->seatsMinimum && ($seats && $result >= $seats))){
						//we do have seats available
						$flag = true;
					}
				}
			}
			if($flag){
				array_push($this->availabilities, $availability);
			}
		}
		if(count($this->availabilities) > 0){
			$this->render();
		}
	}
	public function getSeats($availabilityHelper, $startDate, $startTime, $endDate, $endTime){
		if($availabilityHelper->availability->seats){
			//day based seats
			if($this->appointment === 1/*edit mode*/){
				return $availabilityHelper->availability->seats;
			}
			$result1 = $availabilityHelper->availability->seats - $availabilityHelper->getTotalUsedSeats($availabilityHelper->availability, null, $startDate);
			if($endDate && $startDate != $endDate){
				$result1 = $availabilityHelper->availability->seats - $availabilityHelper->getTotalUsedSeats($availabilityHelper->availability, null, $endDate);
			}
			return $result1;
		}
		if(in_array($availabilityHelper->project->calendarMode, Calendarista_CalendarMode::$SUPPORTS_TIMESLOT_AND_SEATS)){
			//timeslot based seats
			$repo = new Calendarista_TimeslotRepository();
			$timeslot1 = $repo->read($startTime);
			if(!$timeslot1){
				return 0;
			}
			$this->seatsMaximum = $timeslot1->seatsMaximum;
			$this->seatsMinimum = $timeslot1->seatsMinimum;
			if($this->appointment === 1/*edit mode*/){
				return $timeslot1->seats;
			}
			$bookedAvailabilities = $availabilityHelper->getCurrentMonthAvailabilities($startDate);
			$selectedDateTime = strtotime("$startDate $timeslot1->timeslot");
			$usedSeats = $availabilityHelper->timeslotHelper->getUsedSeats($selectedDateTime, $timeslot1->timeslot, $bookedAvailabilities);
			$result2 = $timeslot1->seats ? ($timeslot1->seats - $usedSeats) : $timeslot1->seats;
			
			if($endDate && $startDate != $endDate){
				if(!$result2){
					return $result2;
				}
				$bookedAvailabilities = $availabilityHelper->getCurrentMonthAvailabilities($endDate);
				$selectedDateTime = strtotime("$endDate $timeslot1->timeslot");
				$usedSeats = $availabilityHelper->timeslotHelper->getUsedSeats($selectedDateTime, $timeslot1->timeslot, $bookedAvailabilities);
				$result2 = $timeslot1->seats ? ($timeslot1->seats - $usedSeats) : $timeslot1->seats;
				return $result2;
			}
			if(!$endTime){
				return $result2;
			}
			$timeslot2 = $repo->read($endTime);
			if(!$timeslot2){
				return $result2;
			}
			//we have a start and end time, so return the least number of seats
			$timeslots = $repo->readAllByStartEnd($timeslot1->id, $timeslot2->id);
			$result4 = 0;
			$flag = false;
			foreach($timeslots as $timeslot){
				$selectedDateTime = strtotime("$startDate $timeslot->timeslot");
				$usedSeats = $availabilityHelper->timeslotHelper->getUsedSeats($selectedDateTime, $timeslot->timeslot, $bookedAvailabilities);
				$result3 = $timeslot->seats ? ($timeslot->seats - $usedSeats) : $timeslot->seats;
				if(!$flag){
					$result4 = $result3;
					$flag = true;
					continue;
				}
				if($result3 < $result4){
					$result4 = $result3;
				}
			}
			return $result4;
		}	
		return 0;
	}
	public function selectedAvailability($value){
		if(in_array($value, $this->selectedAvailabilities)){
			return 'checked';
		}
		return null;
	}
	public function render(){
	?>
	<div class="col-xl-12">
		<div class="form-group">
			<label class="form-control-label calendarista-typography--caption1">
				<?php echo $this->stringResources['BOOK_ANOTHER_AVAILABILITY'] ?>
			</label>
			<div>
				<div class="form-check-inline">
					<?php foreach($this->availabilities as $availability): ?>
					<label class="form-check-label">
						<input type="checkbox" class="form-check-input" name="availabilities[]" value="<?php echo $availability->id ?>" <?php echo  $this->selectedAvailability($availability->id); ?>>
						<?php echo $availability->name ?>
					</label>&nbsp;&nbsp;
					<?php endforeach; ?>
				</div>
			</div>
		</div>
	</div>
<?php
	}
}
