<?php
class Calendarista_BookingSeatsTmpl extends Calendarista_TemplateBase{
	public $seats = 0;
	public $availability;
	public $availabilityHelper;
	public $project;
	public $appointment;
	public $seatsMaximum;
	public $seatsMinimum;
	public function __construct(){
		parent::__construct();
		$projectId = (int)$this->getPostValue('projectId');
		$startDate = $this->getPostValue('startDate');
		$startTime = $this->getPostValue('startTime') ? (int)$this->getPostValue('startTime') : null;
		$endTime = $this->getPostValue('endTime') ? (int)$this->getPostValue('endTime') : null;
		$availabilityId = (int)$this->getPostValue('availabilityId');
		$this->appointment = (int)$this->getPostValue('appointment', -1);
		$this->availabilityHelper = new Calendarista_AvailabilityHelper(array(
			'projectId'=>$projectId
			, 'availabilityId'=>$availabilityId
		));
		$this->project = $this->availabilityHelper->project;
		$this->availability = $this->availabilityHelper->availability;
		$this->seatsMaximum = $this->availability->seatsMaximum;
		$this->seatsMinimum = $this->availability->seatsMinimum;
		$this->seats = $this->getSeats($startDate, $startTime, $endTime);
		if($this->seats && $this->seats >= $this->availability->seatsMinimum){
			$this->render();
		}
	}
	public function getSeats($startDate, $startTime, $endTime){
		$result = 0;
		if(in_array($this->project->calendarMode, Calendarista_CalendarMode::$SUPPORTS_TIMESLOT_AND_SEATS)){
			//timeslot based seats
			$result = $this->getSeatsFromIndividualTimeslot($startDate, $startTime, $endTime);
		}
		if(!$result && $this->availability->seats){
			//day based seats
			if($this->appointment === 1/*edit mode*/){
				$result = $this->availability->seats;
			}else{
				$result = $this->availability->seats - $this->availabilityHelper->getTotalUsedSeats($this->availability, null, $startDate);
			}
			$this->seatsMaximum = $this->availability->seatsMaximum;
			$this->seatsMinimum = $this->availability->seatsMinimum;
		}
		return $result;
	}
	public function getSeatsFromIndividualTimeslot($startDate, $startTime, $endTime){
		$repo = new Calendarista_TimeslotRepository();
		$timeslot1 = $repo->read($startTime);
		if(!$timeslot1){
			return 0;
		}
		$this->seatsMaximum = $timeslot1->seatsMaximum;
		$this->seatsMinimum = $timeslot1->seatsMinimum;
		if($this->appointment === 1/*edit mode*/){
			return $timeslot1->seats;
		}
		$bookedAvailabilities = $this->availabilityHelper->getCurrentMonthAvailabilities($startDate);
		$selectedDateTime = strtotime("$startDate $timeslot1->timeslot");
		$usedSeats = $this->availabilityHelper->timeslotHelper->getUsedSeats($selectedDateTime, $timeslot1->timeslot, $bookedAvailabilities);
		$result1 = $timeslot1->seats ? ($timeslot1->seats - $usedSeats) : $timeslot1->seats;
		if(!$endTime){
			return $result1;
		}
		$timeslot2 = $repo->read($endTime);
		if(!$timeslot2){
			return $result1;
		}
		$this->seatsMaximum = $timeslot2->seatsMaximum;
		$this->seatsMinimum = $timeslot2->seatsMinimum;
		//we have a start and end time, so return the least number of seats
		$timeslots = $repo->readAllByStartEnd($timeslot1->id, $timeslot2->id);
		$result3 = 0;
		$flag = false;
		foreach($timeslots as $timeslot){
			$selectedDateTime = strtotime("$startDate $timeslot->timeslot");
			$usedSeats = $this->availabilityHelper->timeslotHelper->getUsedSeats($selectedDateTime, $timeslot->timeslot, $bookedAvailabilities);
			$result2 = $timeslot->seats ? ($timeslot->seats - $usedSeats) : $timeslot->seats;
			if(!$flag){
				$result3 = $result2;
				$flag = true;
				continue;
			}
			if($result2 < $result3){
				$result3 = $result2;
			}
		}
		return $result3;
	}
	public function render(){
	?>
	<div class="col-xl-12">
		<div class="form-group">
			<input type="hidden" name="seatsMinimum" value="<?php echo $this->seatsMinimum ?>">
			<input type="hidden" name="seatsMaximum" value="<?php echo $this->seats ?>">
			<?php if($this->availability->selectableSeats && $this->seats):?>
			<label class="form-control-label calendarista-typography--caption1" for="seats_<?php echo $this->uniqueId ?>">
				<?php echo $this->stringResources['SEATS_LABEL'] ?>
			</label>
			<div>
				<select id="calendarista_seats_<?php echo $this->uniqueId ?>" 
					name="seats"
					class="form-control calendarista-typography--caption1">
					<?php for($i = 0; $i< $this->seats; $i++):?>
					<?php if($this->seatsMaximum > 0 && (($i+1) > $this->seatsMaximum)){continue;}?>
					<?php if(($i+1) < $this->seatsMinimum){continue;}?>
					<option value="<?php echo $i+1 ?>" 
						<?php echo $this->selected('seats', $i+1); ?>><?php echo $i+1 ?></option>
					<?php endfor; ?>
				</select>
			</div>
			<?php elseif($this->seats):?>
			<input type="hidden" name="seats" value="<?php echo $this->seatsMinimum ?>">
			<?php if($this->seats > 1 && $this->availability->displayRemainingSeatsMessage):?>
			<div class="alert alert-warning calendarista-typography--caption1 calendarista-row-single">
				<?php echo sprintf($this->stringResources['SEATS_REMAINING'], $this->seats); ?>
			</div>
			<?php endif; ?>
			<?php else:?>
			<div class="alert alert-warning calendarista-typography--caption1 calendarista-row-single">
				<?php echo $this->stringResources['SEATS_EXHAUSTED']; ?>
			</div>
			<?php endif;?>
		</div>
	</div>
<?php
	}
}
